==> wikitty-api-3.1.2-sources.jar: org/nuiton/wikitty/services/WikittyExtensionMigration.java <==
/*
 * #%L
 * Wikitty :: api
 * 
 * $Id: WikittyExtensionMigration.java 461 2010-10-29 15:19:55Z bpoussin $
 * $HeadURL: http://svn.nuiton.org/svn/wikitty/tags/wikitty-3.1.2/wikitty-api/src/main/java/org/nuiton/wikitty/services/WikittyExtensionMigration.java $
 * %%
 * Copyright (C) 2009 - 2010 CodeLutin, Benjamin Poussin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */
package org.nuiton.wikitty.services;

import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.Wikitty;
import java.util.HashMap;
import java.util.Map;
import org.nuiton.wikitty.WikittyService;

/**
 * Interface used to migrate Wikitty data from one WikittyExtension version
 * to another version
 * 
 * @author poussin
 * @version $Revision: 461 $
 *
 * Last update: $Date: 2010-10-29 17:19:55 +0200 (ven., 29 oct. 2010) $
 * by : $Author: bpoussin $
 */
public interface WikittyExtensionMigration {

    // TODO poussin 20090902 permit configuration of migrationRegistry by spring
    /**
     * use to put migration class for extension.
     * key: extensionName, value: migration class
     */
    static public Map<String, WikittyExtensionMigration> migrationRegistry =
            new HashMap<String, WikittyExtensionMigration>();

    /**
     * Migrate wikitty data from oldExt version to newExt.
     * 
     * @param service Wikitty service that do migration
     * @param wikitty Wikitty object that contains data in old version
     * extension format
     * @param oldExt old extension definition
     * @param newExt new extension definition
     * @return same wikitty as argument if nothing to do, or new wikitty
     * if some modification is done
     */
    public Wikitty migrate(WikittyService service, Wikitty wikitty,
            WikittyExtension oldExt, WikittyExtension newExt);

}

==> wikitty-api-3.2-sources.jar: org/nuiton/wikitty/services/WikittyExtensionMigration.java <==
/*
 * #%L
 * Wikitty :: api
 * 
 * $Id: WikittyExtensionMigration.java 1136 2011-08-12 14:24:03Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/wikitty/tags/wikitty-3.2/wikitty-api/src/main/java/org/nuiton/wikitty/services/WikittyExtensionMigration.java $
 * %%
 * Copyright (C) 2009 - 2010 CodeLutin, Benjamin Poussin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */
package org.nuiton.wikitty.services;

import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.Wikitty;
import java.util.HashMap;
import java.util.Map;
import org.nuiton.wikitty.WikittyService;

/**
 * Interface used to migrate Wikitty data from one WikittyExtension version
 * to another version
 * 
 * @author poussin
 * @version $Revision: 1136 $
 *
 * Last update: $Date: 2011-08-12 16:24:03 +0200 (Fri, 12 Aug 2011) $
 * by : $Author: tchemit $
 */
public interface WikittyExtensionMigration {

    // TODO poussin 20090902 permit configuration of migrationRegistry by spring
    /**
     * use to put migration class for extension.
     * key: extensionName, value: migration class
     */
    static public Map<String, WikittyExtensionMigration> migrationRegistry =
            new HashMap<String, WikittyExtensionMigration>();

    /**
     * Migrate wikitty data from oldExt version to newExt.
     * 
     * @param service Wikitty service that do migration
     * @param wikitty Wikitty object that contains data in old version
     * extension format
     * @param oldExt old extension definition
     * @param newExt new extension definition
     * @return same wikitty as argument if nothing to do, or new wikitty
     * if some modification is done
     */
    public Wikitty migrate(WikittyService service, Wikitty wikitty,
            WikittyExtension oldExt, WikittyExtension newExt);

}
